/*
  Copyright 2019 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner

import android.content.Context
import com.kakao.sdk.common.KakaoSdk
import com.kakao.sdk.common.model.ServerHosts

/**
 * 카카오 SDK 를 초기화합니다. [Application.onCreate] 내에서 호출하는 것을 권장합니다.
 *
 * @param context Android Context
 * @param appKey Kakao Native App Key
 * @param hosts SDK가 바라볼 Host 정보. [KakaoPhase] 를 변경하고 싶은 경우 설정합니다.
 */
@JvmOverloads
fun KakaoSdk.init(
    context: Context,
    appKey: String,
    hosts: ServerHosts = PhasedServerHosts(KakaoPhase.PRODUCTION),
    loggingEnabled: Boolean = false
) {
    this.init(context, appKey, loggingEnabled)
    serverHosts = hosts
}